@@ -1,4 +1,4 @@
-###############################################################################
+##############################################################################
 ###############################################################################
 #                               Getleft
 ###############################################################################
@@ -7,7 +7,7 @@
 # Distributed under the terms of the GPL
 ###############################################################################
 ###############################################################################
-# Version 0.8.5
+# Version 0.8.6
 ###############################################################################
 ###############################################################################
 # This program recursively downloads Web sites, as it goes, it changes absolute
@@ -239,7 +239,9 @@ proc Preprocessing {url} {
         set encoding ""
         catch {set encoding $charSets($Ventana::Rizo::meta(charSet))}
         if {$HtmlParser::pageEncoding!=""} {
-            set encoding $charSets($HtmlParser::pageEncoding)
+            if [catch {set $charSets($HtmlParser::pageEncoding)} encoding] {
+                set encoding ""
+            }
         }
         if {$encoding!=""} {
             HtmlParser::ChangeEncoding $encoding
@@ -782,6 +784,9 @@ proc Download {enlace madre sufix} {
         Ventana::HeadDownloading $enlace $madre
         if {$::Ventana::Rizo::curlError!=0} {
             ::Herramientas::ErrorLog $fileName $enlace
+            if {$::DEBUG==1} {
+                puts "curlError: $::Ventana::Rizo::curlError: $enlace"
+            }
             return 2
         }
         if {$meta(relocate)!=""} {
@@ -1495,8 +1500,8 @@ proc ReadConfig { {confFile {} } } {
             set temp [file join $env(HOME) .Getleft]
             if {[file exists $temp]} {
                 set ficherorc $temp
+                set update 1
             }
-            set update 1
         }
     }
 
@@ -1523,9 +1528,22 @@ proc ReadConfig { {confFile {} } } {
                 set urlIndex $line
             }
             proxy {
-                set options(dirProxy) $line
+                set options(httpProxy) $line
+                set options(ftpProxy)  $line
+                set options(sameProxy) 1
                 set options(proxy) 1
             }
+            httpProxy {
+                set options(httpProxy) $line
+puts "ProxyHttp: $options(httpProxy)"
+            }
+            ftpProxy {
+                set options(ftpProxy)  $line
+puts "ProxyFtp: $options(ftpProxy)"
+            }
+            sameProxy {
+                set options(sameProxy) $line
+            }
             ^language$ {
                 set options(lang) $line
             }
@@ -1598,9 +1616,13 @@ proc SaveConfig {} {
     puts $fichero "\n\[urlIndex\]\n"
     puts $fichero $urlIndex
 
-    if [info exists options(dirProxy)] {
-        puts $fichero "\n\[proxy\]\n"
-        puts $fichero "$options(dirProxy)"
+    if [info exists options(httpProxy)] {
+        puts $fichero "\n\[httpProxy\]\n"
+        puts $fichero "$options(httpProxy)"
+        puts $fichero "\n\[ftpProxy\]\n"
+        puts $fichero "$options(ftpProxy)"
+        puts $fichero "\n\[sameProxy\]\n"
+        puts $fichero "$options(sameProxy)"
     }
 
     puts $fichero "\n\[language\]\n"
@@ -2233,7 +2255,7 @@ if {![winfo exists .menus]} {
     SetEncodings
 
     wm geometry . 300x1
-    wm title . "Getleft v0.8.5"
+    wm title . "Getleft v0.8.6"
 
     . config -menu .menus
 
