@@ -155,6 +155,9 @@ fileIncom       "Plik nie skonczony"
 noContent       "Empty link"
 dir             "Directory"
 current         "Current"
+sameProxy       "Use the same proxy"
+http            "Http:"
+ftp             "Ftp:"
 
 End
 
