@@ -264,6 +264,26 @@ proc RestoreOriginals {} {
     return
 }
 
+###############################################################################
+# SameProxy
+#    Disables or enables the entries for the ftp proxy, depending on
+#    the checkbutton
+###############################################################################
+proc SameProxy {} {
+    global options
+    variable ip
+
+    for {set i 6} {$i<11} {incr i} {
+        if {$options(sameProxy)==1} {
+            $ip($i) configure -state disabled
+        } else {
+            $ip($i) configure -state normal
+        }
+    }
+
+    return
+}
+
 ###############################################################################
 # ConfProxy
 #    Allows the user to enter his proxy data.
@@ -287,19 +307,36 @@ proc ConfProxy {} {
 
     set done 0
 
-    set marcoEx [frame $proxy.marcoEx]
-    set marco   [frame $marcoEx.marco -bd 2 -relief groove]
-    set marcoIn [frame $marco.marcoIn]
+    set marcoEx   [frame $proxy.marcoEx]
+    set marco     [frame $marcoEx.marco -bd 2 -relief groove]
+    set marcoIn   [frame $marco.marcoIn]
+    set marcoHttp [frame $marcoIn.marcoHttp]
+    set marcoFtp  [frame $marcoIn.marcoFtp]
 
-    set ip(1)  [entry $marcoIn.1 -width 3 -bg white -justify  right]
-    set ip(2)  [entry $marcoIn.2 -width 3 -bg white -justify  right]
-    set ip(3)  [entry $marcoIn.3 -width 3 -bg white -justify  right]
-    set ip(4)  [entry $marcoIn.4 -width 3 -bg white -justify  right]
-    set ip(5)  [entry $marcoIn.5 -width 4 -bg white]
-    set punto1 [label $marcoIn.punto1 -text \n. -width 1]
-    set punto2 [label $marcoIn.punto2 -text \n. -width 1]
-    set punto3 [label $marcoIn.punto3 -text \n. -width 1]
-    set colon  [label $marcoIn.colon  -text : -width 2]
+    set label1 [label $marcoHttp.label -textvariable labelDialogs(http)]
+    set ip(1)  [entry $marcoHttp.1 -width 3 -bg white -justify  right]
+    set ip(2)  [entry $marcoHttp.2 -width 3 -bg white -justify  right]
+    set ip(3)  [entry $marcoHttp.3 -width 3 -bg white -justify  right]
+    set ip(4)  [entry $marcoHttp.4 -width 3 -bg white -justify  right]
+    set ip(5)  [entry $marcoHttp.5 -width 4 -bg white]
+    set punto1 [label $marcoHttp.punto1 -text \n. -width 1]
+    set punto2 [label $marcoHttp.punto2 -text \n. -width 1]
+    set punto3 [label $marcoHttp.punto3 -text \n. -width 1]
+    set colon1 [label $marcoHttp.colon1 -text : -width 2]
+
+    set label2 [label $marcoFtp.label  -textvariable labelDialogs(ftp)]
+    set ip(6)  [entry $marcoFtp.6  -width 3 -bg white -justify  right]
+    set ip(7)  [entry $marcoFtp.7  -width 3 -bg white -justify  right]
+    set ip(8)  [entry $marcoFtp.8  -width 3 -bg white -justify  right]
+    set ip(9)  [entry $marcoFtp.9  -width 3 -bg white -justify  right]
+    set ip(10) [entry $marcoFtp.10 -width 4 -bg white]
+    set punto4 [label $marcoFtp.punto4 -text \n. -width 1]
+    set punto5 [label $marcoFtp.punto5 -text \n. -width 1]
+    set punto6 [label $marcoFtp.punto6 -text \n. -width 1]
+    set colon2 [label $marcoFtp.colon2 -text : -width 2]
+
+    set check  [checkbutton $marcoIn.check -textvariable labelDialogs(sameProxy) \
+            -variable options(sameProxy) -command ::Herramientas::SameProxy]
 
     set botones  [frame  $proxy.botones]
     set borrar   [button $botones.borrar   -textvariable labelButtons(clear) \
@@ -314,7 +351,10 @@ proc ConfProxy {} {
     pack $borrar   -side right -padx 9
     pack $botones  -side bottom -fill x
 
-    pack $ip(1) $punto1 $ip(2) $punto2 $ip(3) $punto3 $ip(4) $colon $ip(5) -side left
+    pack $label1 $label2 -side left
+    pack $ip(5)  $colon1 $ip(4) $punto3 $ip(3) $punto2 $ip(2) $punto1 $ip(1) -side right
+    pack $ip(10) $colon2 $ip(9) $punto6 $ip(8) $punto5 $ip(7) $punto4 $ip(6) -side right
+    pack $marcoHttp $marcoFtp $check -fill x
     pack $marcoIn -padx 10 -pady 10
     pack $marco -side bottom
     pack $marcoEx -ipadx 10 -ipady 5
@@ -322,15 +362,15 @@ proc ConfProxy {} {
     focus $ip(1)
 
     bind $proxy <Escape> "$cancelar invoke"
-    for {set i 1;set n 2} {$i<6} {incr i;incr n} {
-        if {$i!=5} {
+    for {set i 1;set n 2} {$i<11} {incr i;incr n} {
+        if {($i!=5)&&($i!=10)} {
             bind $ip($i) <Return>   "focus $ip($n)"
             bind $ip($i) <KP_Enter> "focus $ip($n)"
             bind $ip($i) <Key-Right> {
                 %W selection range 0 0
                 set indice [%W index insert]
                 set final  [%W index end]
-                if {($indice==3)||($indice==$final)} {
+                if {$indice==$final} {
                     focus $::Herramientas::ip([expr [winfo name %W] +1])
                 }
             }
@@ -350,6 +390,39 @@ proc ConfProxy {} {
                 }
             }
         } else {
+            if {$i==5} {
+                bind $ip(5) <Key-Right> {
+                    %W selection range 0 0
+                    set indice [%W index insert]
+                    set final  [%W index end]
+                    if {$indice==$final} {
+                        focus $::Herramientas::ip(6)
+                    }
+                }
+                bind $ip(5) <KeyRelease> {
+                    if {[%W index insert]==4} {
+                        focus $::Herramientas::ip(6)
+                    }
+                }
+                bind $ip(5) <Return> "
+                    focus $ip(6)
+                "
+                bind $ip($i) <KP_Enter> "
+                    focus $ip(6)
+                "
+            } else {
+                bind $ip($i) <KeyRelease> {
+                    if {[%W index insert]==4} {
+                        focus .proxy.botones.aceptar
+                    }
+                }
+                bind $ip($i) <Return> "
+                    focus $ip(6)
+                "
+                bind $ip($i) <KP_Enter> "
+                    focus $ip(6)
+                "
+            }
             bind $ip($i) <KeyPress> {
                 if {[%W index end]==4} {
                     if {("%K"!="Left")&&("%K"!="Return")&&("%K"!="Tab")&&("%K"!="Delete")&&("%K"!="BackSpace")} {
@@ -357,17 +430,6 @@ proc ConfProxy {} {
                     }
                 }
             }
-            bind $ip($i) <KeyRelease> {
-                if {[%W index insert]==4} {
-                    focus .proxy.botones.aceptar
-                }
-            }
-            bind $ip($i) <Return> "
-                focus $aceptar
-            "
-            bind $ip($i) <KP_Enter> "
-                focus $aceptar
-            "
         }
         if {$i!=1} {
             bind $ip($i) <Key-Left> {
@@ -380,29 +442,45 @@ proc ConfProxy {} {
         bind $ip($i) <FocusIn> "$ip($i) selection range 0 end"
     }
 
-    if [info exists options(dirProxy)] {
+    if [info exists options(httpProxy)] {
         regexp {([^\.]+)(?:\.)([^\.]+)(?:\.)([^\.]+)(?:\.)([^\.]+)(?::)(.*)} \
-                 $options(dirProxy) nada ip1 ip2 ip3 ip4 ip5
+                 $options(httpProxy) nada ip1 ip2 ip3 ip4 ip5
         $ip(1) insert insert $ip1
         $ip(2) insert insert $ip2
         $ip(3) insert insert $ip3
         $ip(4) insert insert $ip4
         $ip(5) insert insert $ip5
     }
+    if [info exists options(ftpProxy)] {
+        regexp {([^\.]+)(?:\.)([^\.]+)(?:\.)([^\.]+)(?:\.)([^\.]+)(?::)(.*)} \
+                 $options(ftpProxy) nada ip6 ip7 ip8 ip9 ip10
+        $ip(6)  insert insert $ip6
+        $ip(7)  insert insert $ip7
+        $ip(8)  insert insert $ip8
+        $ip(9)  insert insert $ip9
+        $ip(10) insert insert $ip10
+    }
 
+    SameProxy
     tkwait variable done
 
     if {$done==1} {
-        for {set i 1} {$i<6} {incr i} {
+        for {set i 1} {$i<11} {incr i} {
             set dirProxy($i) [$ip($i) get]
         }
-        set options(dirProxy) "$dirProxy(1).$dirProxy(2).$dirProxy(3).$dirProxy(4):$dirProxy(5)"
+        set options(httpProxy) "$dirProxy(1).$dirProxy(2).$dirProxy(3).$dirProxy(4):$dirProxy(5)"
+        if {$options(sameProxy)==0} {
+            set options(ftpProxy) "$dirProxy(6).$dirProxy(7).$dirProxy(8).$dirProxy(9):$dirProxy(10)"
+        } else {
+            set options(ftpProxy) $options(httpProxy)
+        }
         SaveConfig
     } elseif {$done==2} {
         for {set i 1} {$i<6} {incr i} {
             $ip($i) delete 0 end
         }
-        catch {unset options(dirProxy)}
+        catch {unset options(httpProxy)}
+        catch {unset options(ftpProxy)}
         SaveConfig
     }
 
@@ -518,4 +596,60 @@ proc ShowErrorLog {} {
     return
 }
 
+proc DummyProc {newSock addr port} {
+    variable proxyIp
+
+    regexp {(.*)(\.)} $addr nada myIp
+
+    set proxyIp $myIp.1
+
+    return
+}
+
+proc GuessProxyIp {} {
+    variable proxyIp
+
+    set serverSocket [socket -server ::Herramientas::DummyProc 11453]
+
+    set channel [socket [info hostname] 11453]
+
+    tkwait variable ::Herramientas::proxyIp
+
+    close $serverSocket
+
+    puts "La direccion: $proxyIp"
+
+    return
+}
+
+proc GuessProxyPort {} {
+    variable proxyIp
+    variable proxyPort
+
+    package require http
+
+    http::config -proxyhost $proxyIp
+    for {set i 80} {$i<=10000} {incr i} {
+        http::config -proxyport $i
+        if {[catch {http::geturl http://freshmeat.net/appindex/1999/07/17/932219913.html} token]} {
+            continue
+        }
+        if {[::http::status $token]=="ok"} {
+            regexp {( [0-9][0-9][0-9] )} [::http::code $token] code
+            if {$code==200} {
+                set proxyPort $i
+                break
+            }
+        }
+    }
+    if {$i<=1000} {
+    tk_messageBox -message "El proxy: es $proxyIp:$proxyPort" -type ok -icon info
+    } else {
+    tk_messageBox -message "No se encontr el proxy" -type ok -icon info
+    }
+    package forget http
+
+    return
+}
+
 }
