@@ -238,7 +238,7 @@ proc TidyDescription {} {
             regsub {#} $entity {} entity
 
 # Eventually this should be replaced wirh "string is number"
-            if {[regexp {[0-9]+} $entity]} {
+            if {[regexp {^[0-9]+$} $entity]} {
                 set new [format %c $entity]
                 regsub -all {([\\])} $new {\\\1} new
             } else {
